@@ -5,10 +5,10 @@ from .type import RequestType
 
 def parking_service_find(self, plate_number, plate_color, openid, sub_mchid=None):
     """查询车牌服务开通信息
-    :param plate_number: 车牌号，示例值：'粤B888888'
-    :param plate_color: 车牌颜色，车牌颜色，枚举值：BLUE：蓝色，GREEN：绿色，YELLOW：黄色，BLACK：黑色，WHITE：白色，LIMEGREEN：黄绿色
-    :param openid: 用户标识，示例值：'oUpF8uMuAJOM2pxb1Q'
-    :param sub_mchid: (服务商模式)子商户的商户号，由微信支付生成并下发。示例值：'1900000109'  
+    :param plate_number: 车牌号，示例值:'粤B888888'
+    :param plate_color: 车牌颜色，车牌颜色，枚举值:BLUE:蓝色，GREEN:绿色，YELLOW:黄色，BLACK:黑色，WHITE:白色，LIMEGREEN:黄绿色
+    :param openid: 用户标识，示例值:'oUpF8uMuAJOM2pxb1Q'
+    :param sub_mchid: (服务商模式)子商户的商户号，由微信支付生成并下发。示例值:'1900000109'  
     """
     path = '/v3/vehicle/parking/services/find?appid=%s' % self._appid
     if plate_number:
@@ -33,14 +33,14 @@ def parking_service_find(self, plate_number, plate_color, openid, sub_mchid=None
 
 def parking_enter(self, out_parking_no, plate_number, plate_color, start_time, parking_name, free_duration, notify_url=None, sub_mchid=None):
     """创建停车入场
-    :param out_parking_no: 商户入场id，商户侧入场标识id，在同一个商户号下唯一，示例值：'1231243'
-    :param plate_number: 车牌号，示例值：'粤B888888'
-    :param plate_color: 车牌颜色，车牌颜色，枚举值：BLUE：蓝色，GREEN：绿色，YELLOW：黄色，BLACK：黑色，WHITE：白色，LIMEGREEN：黄绿色
-    :param notify_url: 回调通知url，接受入场状态变更回调通知的url，只接受https，示例值：https://yoursite.com/wxpay.html
-    :param start_time: 入场时间，示例值：'2017-08-26T10:43:39+08:00'
-    :param parking_name: 停车场名称，示例值：'欢乐海岸停车场'
-    :param free_duration: 免费时长，单位为秒，示例值：3600
-    :param sub_mchid: (服务商模式)子商户的商户号，由微信支付生成并下发。示例值：'1900000109'      
+    :param out_parking_no: 商户入场id，商户侧入场标识id，在同一个商户号下唯一，示例值:'1231243'
+    :param plate_number: 车牌号，示例值:'粤B888888'
+    :param plate_color: 车牌颜色，车牌颜色，枚举值:BLUE:蓝色，GREEN:绿色，YELLOW:黄色，BLACK:黑色，WHITE:白色，LIMEGREEN:黄绿色
+    :param notify_url: 回调通知url，接受入场状态变更回调通知的url，只接受https，示例值:https://yoursite.com/wxpay.html
+    :param start_time: 入场时间，示例值:'2017-08-26T10:43:39+08:00'
+    :param parking_name: 停车场名称，示例值:'欢乐海岸停车场'
+    :param free_duration: 免费时长，单位为秒，示例值:3600
+    :param sub_mchid: (服务商模式)子商户的商户号，由微信支付生成并下发。示例值:'1900000109'      
     """
     params = {}
     if out_parking_no:
@@ -83,26 +83,26 @@ def parking_order(self, description, out_trade_no, total, parking_id, plate_numb
                   end_time, parking_name, charging_duration, device_id, trade_scene='PARKING', profit_sharing='N',
                   currency='CNY', attach=None, goods_tag=None, notify_url=None, appid=None, sub_appid=None, sub_mchid=None):
     """停车扣费受理
-    :param description: 服务描述，商户自定义字段，用于交易账单中对扣费服务的描述。示例值：'停车场扣费'
-    :param out_trade_no: 商户订单号，商户系统内部订单号，只能是数字、大小写字母，且在同一个商户号下唯一，示例值：'20150806125346'
-    :param notify_url: 回调通知url，只接受https，示例值：'https://yoursite.com/wxpay.html'
-    :param total: 订单总金额，单位为分，只能为整数，示例值：888
-    :param parking_id: 停车入场id，通过入场通知接口获取的入场id，示例值：'5K8264ILTKCH16CQ250'
-    :param plate_number: 车牌号，仅包括省份+车牌，不包括特殊字符。示例值：'粤B888888'
-    :param plate_color: 车牌颜色，枚举值：BLUE：蓝色，GREEN：绿色，YELLOW：黄色，BLACK：黑色，WHITE：白色，LIMEGREEN：黄绿色，示例值：BLUE
-    :param start_time: 入场时间，示例值：'2017-08-26T10:43:39+08:00'
-    :param end_time: 出场时间，示例值：'2017-08-26T10:43:39+08:00'
-    :param parking_name: 停车场名称，示例值：'欢乐海岸停车场'
-    :param charging_duration: 计费时长，单位为秒，示例值：3600
-    :param device_id: 停车场设备id，示例值：'12313'
-    :param trade_scene: 交易场景值，目前支持'PARKING'：车场停车场景
-    :param profit_sharing: 分账标识，枚举值：'Y'：是，需要分账，'N'：否，不分账，字母要求大写，不传默认不分账。
-    :param currency: 货币类型，目前只支持人民币：'CNY'
-    :param attach: 附加数据，在查询API和支付通知中原样返回，可作为自定义参数使用，示例值：'深圳分店'
-    :param goods_tag: 订单优惠标记，代金券或立减优惠功能的参数，示例值：WXG
-    :param appid: 应用ID，可不填，默认传入初始化时的appid，示例值：'wx1234567890abcdef'
-    :param sub_appid: (服务商模式)子商户应用ID，示例值：'wxd678efh567hg6999'
-    :param sub_mchid: (服务商模式)子商户的商户号，由微信支付生成并下发。示例值：'1900000109'     
+    :param description: 服务描述，商户自定义字段，用于交易账单中对扣费服务的描述。示例值:'停车场扣费'
+    :param out_trade_no: 商户订单号，商户系统内部订单号，只能是数字、大小写字母，且在同一个商户号下唯一，示例值:'20150806125346'
+    :param notify_url: 回调通知url，只接受https，示例值:'https://yoursite.com/wxpay.html'
+    :param total: 订单总金额，单位为分，只能为整数，示例值:888
+    :param parking_id: 停车入场id，通过入场通知接口获取的入场id，示例值:'5K8264ILTKCH16CQ250'
+    :param plate_number: 车牌号，仅包括省份+车牌，不包括特殊字符。示例值:'粤B888888'
+    :param plate_color: 车牌颜色，枚举值:BLUE:蓝色，GREEN:绿色，YELLOW:黄色，BLACK:黑色，WHITE:白色，LIMEGREEN:黄绿色，示例值:BLUE
+    :param start_time: 入场时间，示例值:'2017-08-26T10:43:39+08:00'
+    :param end_time: 出场时间，示例值:'2017-08-26T10:43:39+08:00'
+    :param parking_name: 停车场名称，示例值:'欢乐海岸停车场'
+    :param charging_duration: 计费时长，单位为秒，示例值:3600
+    :param device_id: 停车场设备id，示例值:'12313'
+    :param trade_scene: 交易场景值，目前支持'PARKING':车场停车场景
+    :param profit_sharing: 分账标识，枚举值:'Y':是，需要分账，'N':否，不分账，字母要求大写，不传默认不分账。
+    :param currency: 货币类型，目前只支持人民币:'CNY'
+    :param attach: 附加数据，在查询API和支付通知中原样返回，可作为自定义参数使用，示例值:'深圳分店'
+    :param goods_tag: 订单优惠标记，代金券或立减优惠功能的参数，示例值:WXG
+    :param appid: 应用ID，可不填，默认传入初始化时的appid，示例值:'wx1234567890abcdef'
+    :param sub_appid: (服务商模式)子商户应用ID，示例值:'wxd678efh567hg6999'
+    :param sub_mchid: (服务商模式)子商户的商户号，由微信支付生成并下发。示例值:'1900000109'     
     """
     params = {}
     amount = {}
@@ -186,8 +186,8 @@ def parking_order(self, description, out_trade_no, total, parking_id, plate_numb
 
 def parking_order_query(self, out_trade_no, sub_mchid=None):
     """停车扣费订单查询
-    :param out_trade_no: 商户订单号，商户系统内部订单号，只能是数字、大小写字母，且在同一个商户号下唯一，示例值：'20150806125346'
-    :param sub_mchid: (服务商模式)子商户的商户号，由微信支付生成并下发。示例值：'1900000109'
+    :param out_trade_no: 商户订单号，商户系统内部订单号，只能是数字、大小写字母，且在同一个商户号下唯一，示例值:'20150806125346'
+    :param sub_mchid: (服务商模式)子商户的商户号，由微信支付生成并下发。示例值:'1900000109'
     """
     if out_trade_no:
         path = '/v3/vehicle/transactions/out-trade-no/%s' % out_trade_no
